class context:
    """
    Use this class as a decorator around methods, properties, or cached
    properties to add the wrapped value (or result for callables) to
    the template context. Works for all Django View classes.
    Requires Python 3.6+
    """

    def __init__(self, func):
        self.func = func

    def __set_name__(self, owner, name):

        if hasattr(self.func, '__set_name__'):
            self.func.__set_name__(owner, name)

        if not hasattr(owner, '_context_fields'):
            owner._context_fields = set()
        owner._context_fields.add(name)

        if not getattr(owner, 'get_context_data', False):

            def get_context_data(_self, **kwargs):
                return super(_self, owner).get_context_data(**kwargs)

            owner.get_context_data = get_context_data

        if not getattr(owner, '_context_patched', False):
            old_get_context_data = owner.get_context_data

            def new_get_context_data(_self, **kwargs):
                result = old_get_context_data(_self, **kwargs)
                for name in _self._context_fields:
                    attr = getattr(_self, name)
                    if callable(attr):
                        attr = attr()
                    result.setdefault(name, attr)
                return result

            owner.get_context_data = new_get_context_data
            owner._context_patched = True

    def __get__(self, instance, cls=None):
        if hasattr(self.func, '__get__'):
            return self.func.__get__(instance, cls)
        return self.func



#!/usr/bin/env python
import sys
from os import path
from setuptools import setup, find_packages

CURRENT_PYTHON = sys.version_info[:2]
REQUIRED_PYTHON = (3, 6)
if CURRENT_PYTHON < REQUIRED_PYTHON:
    sys.stderr.write(
        """
==========================
Unsupported Python version
==========================
django-context-decorator requires Python {}.{}, but you're trying to
install it on Python {}.{}.
""".format(
            *(REQUIRED_PYTHON + CURRENT_PYTHON)
        )
    )
    sys.exit(1)

# Get the long description from the relevant file
here = path.abspath(path.dirname(__file__))
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='django_context_decorator',
    version='1.2.0',
    author='Tobias Kunze',
    author_email='r@rixx.de',
    license='Apache License 2.0',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Framework :: Django',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'License :: OSI Approved',
        'License :: OSI Approved :: Apache Software License',
    ],
    description='A context decorator for Django views',
    long_description=long_description,
    python_requires='>=3.6',
    keywords='django context templates',
    py_modules=['django_context_decorator'],
    url='https://github.com/rixx/django_context_decorator',
)
